| bhattacharyya_mvnorm | R Documentation |
Estimates means and covariances per category and computes Bhattacharyya distance and affinity (exp(-distance)) under the assumption of multivariate normality.
bhattacharyya_mvnorm(data, features, category_col, eps = 1e-06)
data |
Data frame. |
features |
Character vector of numeric feature columns. |
category_col |
String; column with exactly two categories. |
eps |
Small ridge constant added to covariance matrices to improve numerical stability. |
A list with distance and affinity (exp(-distance)).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.