scale_colour_phontrast: Okabe-Ito discrete color and fill scales

View source: R/theme_phontrast.R

scale_colour_phontrastR Documentation

Okabe-Ito discrete color and fill scales

Description

Discrete ggplot2 scales built on phontrast_palette(). These are the default scales for all phontrast plotting functions and can be added to any ggplot to match the package's visual identity.

Usage

scale_colour_phontrast(...)

scale_color_phontrast(...)

scale_fill_phontrast(...)

Arguments

...

Passed to ggplot2::discrete_scale() (e.g. name, labels, guide).

Value

A ggplot2 scale object.

Examples

if (requireNamespace("ggplot2", quietly = TRUE)) {
  ggplot2::ggplot(iris, ggplot2::aes(Sepal.Length, Sepal.Width,
                                     color = Species)) +
    ggplot2::geom_point() +
    scale_color_phontrast() +
    theme_phontrast()
}

phontrast documentation built on Oct. 7, 2026, 5:06 p.m.